from django.core.exceptions import ObjectDoesNotExist, MultipleObjectsReturned
from django.core.management.base import NoArgsCommand
from django.template.defaultfilters import slugify
from django.utils.html import strip_tags

import MySQLdb

from program.models import BroadcastFormat, Host, Show

USER = 'helsinki'
PASSWD = 'helsinki'
DB = 'helsinki'

TALK = BroadcastFormat.objects.get(pk=1)


class Command(NoArgsCommand):
    help = 'Import shows from the current program'

    def handle_noargs(self, **options):
        connection = MySQLdb.connect(user=USER, passwd=PASSWD, db=DB)
        cursor = connection.cursor()

        cursor.execute("""SELECT titel, beschreibung, web, macher
FROM sendungen
WHERE letzter_termin > current_date AND titel NOT LIKE 'Musikprogramm' AND titel NOT LIKE '%%(Wiederholung)'
ORDER BY titel, beginn, ende""")

        counter = 0

        for titel, beschreibung, web, macher in cursor.fetchall():
            titel = strip_tags(titel)
            beschreibung = strip_tags(beschreibung)

            slug = slugify(titel)

            hosts = []

            for macher in macher.split(','):
                macher = macher.strip()
                try:
                    host = Host.objects.get(name=macher)
                except MultipleObjectsReturned:
                    self.stdout.write(self.style.NOTICE, f'multiple hosts with name "{macher}" found')
                except ObjectDoesNotExist:
                    self.stdout.write(self.style.NOTICE, f'host with name "{macher}" not found')
                else:
                    hosts.append(host)

            try:
                show = Show.objects.get(name=titel)
                self.stdout.write(self.style.NOTICE, f'sendung "{titel}" already imported as show "{show}"')
            except ObjectDoesNotExist:
                show = Show(broadcastformat=TALK, name=titel, slug=slug, short_description='FIXME',
                            description=beschreibung)
                try:
                    show.save()
                    counter += 1
                except:
                    self.stdout.write(self.style.NOTICE, f'sendung "{titel}" could not be imported')
                else:
                    for h in hosts:
                        show.hosts.add(h)
                        show.save()

        cursor.close()
        connection.close()

        self.stdout.write(self.style.SUCCESS, f'{counter} shows imported')
